<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>Tout effacer</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>Centre de notification</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Tout effacer</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>Retirer</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Épingler</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>Réglages des notifications</translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>À l&apos;instant</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>Il y a %1 minutes</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation>Il y a 1 heure</translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>Il y a %1 heures</translation>
    </message>
    <message>
        <source>Yesterday </source>
        <translation>Hier</translation>
    </message>
</context>
</TS>